﻿using ArtOfTest.WebAii.Controls.HtmlControls;
using ArtOfTest.WebAii.Core;
using NUnit.Framework;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Test
{
  [TestFixture]
  public class SampleWebTest
  {
    private Manager manager;
    private const string startURL = "http://localhost:64893/index.aspx";
    private const string popupURL = "http://localhost:64893/popup.aspx";

    [SetUp]
    public void Setup ()
    {
      var webSettings = new Settings.WebSettings (BrowserType.InternetExplorer, "about:blank")
        {
          Browser = BrowserExecutionType.InternetExplorer,
          DefaultBrowser = BrowserType.InternetExplorer,
          KillBrowserProcessOnClose = true
        };
      var settings = new Settings (webSettings, null)
        {
          ClientReadyTimeout = 20000,
          ElementWaitTimeout = 20000,
          ExecuteCommandTimeout = 20000,
          UnexpectedDialogAction = UnexpectedDialogAction.DoNotHandle
        };
      manager = new Manager (settings);
      manager.Start ();
      manager.LaunchNewBrowser (BrowserType.InternetExplorer, true);
    }

    [Test]
    public void PopupSampleTest ()
    {
      var browser = manager.ActiveBrowser;
      browser.NavigateTo(startURL);
      var openBtn = GetInputButton(browser, "openWindowBtn");
      openBtn.Click();

      manager.WaitForNewBrowserConnect(popupURL, false, 20000);
      var popup = manager.ActiveBrowser;
      var closeBtn = GetInputButton(popup, "closeWindowBtn");
      closeBtn.Click(true);

      System.Threading.Thread.Sleep(5000);

      var cb1 = GetInputCheckBox(browser, "cb1");
      cb1.Check(true, true);
      var cb2 = GetInputCheckBox(browser, "cb2");
      cb2.Check(true, true);
      var cb3 = GetInputCheckBox(browser, "cb3");
      cb3.Check(true, true);

      closeBtn = GetInputButton(browser, "closeWindowBtn");
      closeBtn.Click(true);
    }

    private HtmlInputButton GetInputButton (Browser browser, string id)
    {
      var btnE = browser.WaitForElement (new HtmlFindExpression ("tagname=input", "type=button", "id=" + id),
                                     20000, false);
      return new HtmlInputButton (btnE);
    }

    private HtmlInputCheckBox GetInputCheckBox (Browser browser, string id)
    {
      var cbxE = browser.WaitForElement (new HtmlFindExpression ("tagname=input", "type=checkbox", "id=" + id),
                                     20000, false);
      return new HtmlInputCheckBox (cbxE);
    }
  }
}
